@@ -1,8 +1,9 @@
 import torch
 from torch.utils.data import Dataset
+import numpy as np
 
 
-class COTMDataset(Dataset):
+class CTMDataset(Dataset):
 
     """Class to load BOW dataset."""
 
@@ -26,3 +27,5 @@ class COTMDataset(Dataset):
         X_bert = torch.FloatTensor(self.X_bert[i])
 
         return {'X': X, 'X_bert': X_bert}
+
+
